import React, { useMemo } from 'react';

import { useSelector } from 'react-redux';

import { getIsFetching } from '../selectors';
import { IFetchShapes, IRootStore } from '../types';

export type IProps = {
	children: React.ReactNode;
	path: string;
	placeholder?: React.ReactElement;
	shape?: IFetchShapes;
};

const FetchLoader: React.FC<IProps> = (props) => {
	const { children, path, shape } = props;

	const isFetching = useSelector((state: IRootStore) => getIsFetching([state, path]));

	const placeholder = useMemo(() => {
		if (shape === IFetchShapes.input) {
			return (
				<>
					<div className="h-4 bg-gray-200 rounded w-1/4" />
					<div className="mt-1">
						<div className="h-7 bg-gray-200 rounded" />
					</div>
				</>
			);
		}
	}, [shape]);

	return (
		<>
			{isFetching ? (
				<div className="animate-pulse flex-1 py-1">{props.placeholder || placeholder}</div>
			) : (
				children
			)}
		</>
	);
};

export default FetchLoader;
