import React from 'react';

import { useSelector } from 'react-redux';

import FetchLoader, { IProps as IFetchLoaderProps } from '../components/FetchLoader';
import { getFetchState } from '../selectors';
import { FetchMethods, IFetchState, IRootStore } from '../types';

type IFetchReturn = {
	FetchLoader: React.FC<any>;
	state: IFetchState;
};

type IUseFetchOptions = {
	fetchPath: {
		method: FetchMethods;
		url: string;
	};
	loaderProps?: Omit<IFetchLoaderProps, 'children' | 'path'>;
};

const useFetch = ({ fetchPath, loaderProps }: IUseFetchOptions): IFetchReturn => {
	const path = `${fetchPath.url}.${fetchPath.method}`;

	const { isError, isFetching, isLoaded } = useSelector((state: IRootStore) => getFetchState([state, path]));

	const Loader = React.useMemo(() => {
		const LoaderComponent: React.FC<{ children: React.ReactNode }> = ({ children }) => {
			return (
				<FetchLoader {...loaderProps} path={path}>
					{children}
				</FetchLoader>
			);
		};
		return LoaderComponent;
	}, [loaderProps, path]);

	return {
		state: {
			isError,
			isFetching,
			isLoaded,
		},
		FetchLoader: Loader,
	};
};

export default useFetch;
