import { path, propOr } from 'ramda';

import memoize from 'proxy-memoize';

import { IFetchState, IRootStore } from '@treejs/api/types';
import { ROOT_REDUCER_NAME } from '@treejs/constants/redux';

import { API_REDUCER_NAME, INITIAL_FETCH_STATE } from './constants';

const pickUpState = (state: IRootStore, url: string): IFetchState => {
	const urlStore = path([ROOT_REDUCER_NAME, API_REDUCER_NAME], state);
	return propOr({}, url, urlStore);
};

export const getFetchState = memoize<[IRootStore, string], IFetchState>(([state, fetchUrl]) => {
	return pickUpState(state, fetchUrl) || INITIAL_FETCH_STATE;
});

export const getIsFetching = memoize<[IRootStore, string], IFetchState['isFetching']>(([state, fetchUrl]) => {
	return pickUpState(state, fetchUrl).isFetching;
});

export const getIsLoaded = memoize<[IRootStore, string], IFetchState['isLoaded']>(([state, fetchUrl]) => {
	return pickUpState(state, fetchUrl).isLoaded;
});

export const getIsError = memoize<[IRootStore, string], IFetchState['isError']>(([state, fetchUrl]) => {
	return pickUpState(state, fetchUrl).isError;
});
