import { createSlice, PayloadAction } from '@reduxjs/toolkit';

import { AUTH_REDUCER_NAME } from './constants';
import { IAuthOption, IUpdateAuthOption } from './types';

const initialState: IAuthOption = {
	authenticated: false,
	accessToken: null,
	refreshToken: null,
	userId: null,
};

const authSlice = createSlice({
	name: AUTH_REDUCER_NAME,
	initialState,
	reducers: {
		setAttrubutes: (state, action: PayloadAction<IAuthOption>) => {
			return {
				...state,
				...action.payload,
			};
		},
		updateAttribute: (state, action: PayloadAction<IUpdateAuthOption>) => {
			return {
				...state,
				[action.payload.key]: action.payload.value,
			};
		},
	},
});

export const setAttrubutes = authSlice.actions.setAttrubutes as <T>(attributes: IAuthOption<T>) => PayloadAction;
export const updateAttribute = authSlice.actions.updateAttribute as <T>(
	attribute: IUpdateAuthOption<T>
) => PayloadAction<IUpdateAuthOption<T>>;

export default authSlice.reducer;
