import React, { ReactNode, useCallback } from 'react';

import cx from 'classnames';

import { STATUS } from '@treejs/types/common';

export type ButtonType = {
	disabled?: boolean;
	label: string | ReactNode;
	onClick?: (e?: any) => void | Promise<void>;
	/**
	 * Define color
	 */
	status?: STATUS;
	type?: 'submit' | 'reset' | 'button';
};

const Button: React.FC<ButtonType> = (props) => {
	const { disabled, onClick, status = STATUS.none, label, type = 'button' } = props;

	const handleOnClick = useCallback(() => {
		if (onClick) {
			onClick();
		}
	}, [onClick]);

	return (
		<button
			className={cx('button', {
				'button--none': status === STATUS.none,
				'button--info': status === STATUS.info,
				'button--success': status === STATUS.success,
				'button--warning': status === STATUS.warning,
				'button--error': status === STATUS.error,
			})}
			onClick={handleOnClick}
			disabled={disabled}
			type={type}
		>
			{label}
		</button>
	);
};

Button.displayName = 'Button';

export default Button;
