import React, { useCallback } from 'react';

import cx from 'classnames';

type IProps = {
	border?: boolean;
	children?: any;
	hasValue: boolean;
	hover: boolean;
	isSelected: boolean;
	isToday: boolean;
	onClick?: (date: Date) => void;
	value?: Date;
};

const CalendarCell: React.FC<IProps> = (props) => {
	const { hover, hasValue, isToday, isSelected, onClick, children, value, border } = props;

	const handleClick = useCallback(() => {
		if (onClick && value) {
			const date = new Date(value);
			onClick(date);
		}
	}, [value, onClick]);

	return (
		<div
			className={cx('table-cell text-center align-top p-1', {
				'hover:bg-focus cursor-pointer': hover && hasValue,
				'border border-whitespace': hasValue && border,
				'bg-primary-light': isToday,
				'bg-active-light': isSelected,
			})}
			onClick={handleClick}
		>
			{children}
		</div>
	);
};

export default CalendarCell;
