import React, { useCallback, useMemo } from 'react';

import { format as setFormat, parse } from 'date-fns';

import Calendar from '../../Calendar/components/Calendar';
import { ModalId } from '../../Modal/types';

type IProps = {
	closeModal: (id: ModalId) => void;
	format?: ModalId;
	name: ModalId;
	onChange: (value: string) => void;
	value: string;
};

const DatePickerModal: React.FC<IProps> = (props) => {
	const { onChange, closeModal, name, value, format = 'dd.MM.yyyy' } = props;

	const setActiveOption = useCallback(
		(newValue: Date) => {
			if (onChange) {
				onChange(setFormat(newValue, format));
			}
			closeModal(name);
		},
		[onChange, closeModal, name, format]
	);

	const date = useMemo(() => {
		return parse(value, format, new Date());
	}, [value]);

	return <Calendar value={date} onDayClick={setActiveOption} hover />;
};

export default DatePickerModal;
