import React, { useCallback, useEffect, useState } from 'react';

import { useDispatch } from 'react-redux';

import { ModalId } from '@treejs/components/Modal/types';
import { STATUS } from '@treejs/types/common';
import { IHTMLElement } from '@treejs/types/form';

import { closeModal, openModal } from '../Modal/actions';
import { addModalComponent } from '../Modal/utils';
import TextField from '../TextField';
import DatePickerModal from './components/DatePickerModal';

export type IDatePickerFieldProps<V = string> = {
	format?: string;
	status?: STATUS;
	value?: Date;
} & IHTMLElement<V>;

const DatePicker: React.FC<IDatePickerFieldProps> = (props) => {
	const { onBlur, onChange, title, status, name } = props;

	const dispatch = useDispatch();

	const [value, setValue] = useState(null);

	useEffect(() => {
		setValue(props.value);
	}, [props.value]);

	const handleCloseModal = useCallback((id: ModalId) => dispatch(closeModal(id)), []);

	const handleBlur = useCallback((newValue: string, e: React.FocusEvent): void => {
		if (onBlur) {
			onBlur(newValue, e);
		}
	}, []);

	const handleDateClick = useCallback((newValue: string): void => {
		setValue(newValue);
		if (onChange) {
			onChange(newValue, null);
		}
	}, []);

	const handleOpenModal = useCallback((): void => {
		addModalComponent(
			name,
			<DatePickerModal name={name} value={value} closeModal={handleCloseModal} onChange={handleDateClick} />
		);
		dispatch(openModal({ id: name, title, width: 300 }));
	}, [name, value, title]);

	return (
		<TextField
			name={name}
			title={title}
			onClick={handleOpenModal}
			onFocus={handleOpenModal}
			onBlur={handleBlur}
			value={value}
			status={status}
			readonly
		/>
	);
};

export default DatePicker;
