import React from 'react';
import { compose, ifElse, mapObjIndexed, values } from 'ramda';

import cx from 'classnames';

import { GRID_SIZE, VERTICAL_ALIGN } from '../types';

type IGridProps = {
	children?: React.ReactElement | React.ReactElement[];
	className?: string;
	cols?: Partial<Record<GRID_SIZE, number>> | number;
	space?: number;
	vertical?: VERTICAL_ALIGN;
};

export const Grid: React.FC<IGridProps> = ({
	cols = 1,
	space = 4,
	className,
	children,
	vertical,
}): React.ReactElement => {
	return (
		<div
			className={cx(
				'grid',
				className,
				{
					'grid-items-start': vertical === VERTICAL_ALIGN.TOP,
					'grid-items-center': vertical === VERTICAL_ALIGN.CENTER,
					'grid-items-end': vertical === VERTICAL_ALIGN.BOTTOM,
				},
				ifElse(
					(val: any) => typeof val === 'number',
					() => `grid-cols-${cols}`,
					compose(
						values,
						mapObjIndexed((size, breakpoint) => `${breakpoint}:grid-cols-${size}`)
					)
				)(cols),
				{
					[`gap-${space}`]: space !== 0,
				}
			)}
		>
			{children}
		</div>
	);
};

Grid.displayName = 'Grid';

export default Grid;
