import React from 'react';
import { compose, ifElse, isNil, mapObjIndexed, values } from 'ramda';

import cx from 'classnames';

import { GRID_SIZE, VERTICAL_ALIGN } from '../types';

type IGridColProps = {
	children?: React.ReactElement | React.ReactElement[] | string;
	className?: string;
	colSpan?: Partial<Record<GRID_SIZE, number>> | number;
	end?: number;
	rowSpan?: Partial<Record<GRID_SIZE, number>> | number;
	start?: number;
	vertical?: VERTICAL_ALIGN;
};

export const GridCol = (props: IGridColProps): React.ReactElement => {
	const { start, end, colSpan, rowSpan, children, className, vertical } = props;
	return (
		<div
			className={cx(
				className,
				{
					[`col-start-${start}`]: !isNil(start),
					[`col-end-${end}`]: !isNil(end),
				},
				{
					'grid-col-start': vertical === VERTICAL_ALIGN.TOP,
					'grid-col-center': vertical === VERTICAL_ALIGN.CENTER,
					'grid-col-end': vertical === VERTICAL_ALIGN.BOTTOM,
				},
				ifElse(
					(val: any) => typeof val === 'number',
					() => `col-span-${colSpan}`,
					compose(
						values,
						mapObjIndexed((size, breakpoint) => `${breakpoint}:col-span-${size}`)
					)
				)(colSpan),
				ifElse(
					(val: any) => typeof val === 'number',
					() => `row-span-${colSpan}`,
					compose(
						values,
						mapObjIndexed((size, breakpoint) => `${breakpoint}:row-span-${size}`)
					)
				)(rowSpan)
			)}
		>
			{children}
		</div>
	);
};

GridCol.displayName = 'GridCol';

export default GridCol;
