import React from 'react';

import cx from 'classnames';
import { FaCheckCircle, FaExclamationCircle, FaExclamationTriangle, FaHandPeace, FaInfoCircle } from 'react-icons/fa';

import { STATUS } from '@treejs/types/common';

type IProps = {
	children?: React.ReactElement | string;
	filled?: boolean;
	status: STATUS;
	title?: string;
};

function Message(props: IProps) {
	const { status = STATUS.none, title, children, filled = false } = props;
	return (
		<div
			className={cx('message', {
				'message--filled': filled,
				'message--none': status === STATUS.none,
				'message--info': status === STATUS.info,
				'message--success': status === STATUS.success,
				'message--warning': status === STATUS.warning,
				'message--error': status === STATUS.error,
			})}
		>
			<div className="inline-block align-middle mr-4 text-xl">
				{status === STATUS.info && <FaInfoCircle />}
				{status === STATUS.success && <FaCheckCircle />}
				{status === STATUS.warning && <FaExclamationTriangle />}
				{status === STATUS.error && <FaExclamationCircle />}
				{status === STATUS.none && <FaHandPeace />}
			</div>
			<div className="text-xl font-normal max-w-full flex-initial">
				{title}
				<div className="text-sm font-base">{children}</div>
			</div>
		</div>
	);
}

export default Message;
