import React, { useCallback } from 'react';

import { useDispatch } from 'react-redux';

import { STATUS } from '@treejs/types/common';

import Button from '../../Button';
import { openModal } from '../actions';
import { ModalState } from '../types';
import { addModalComponent } from '../utils';

type IProps = {
	component: React.ReactElement;
	modalTitle: string;
	properties?: { [key: string]: any };
	status?: STATUS;
	title: string;
} & ModalState;

const AddModalButton: React.FC<IProps> = (props) => {
	const { id: name, title, modalTitle, component, width, status, properties } = props;

	const dispatch = useDispatch();

	const handleClick = useCallback((): void => {
		addModalComponent(name, component);
		dispatch(openModal({ id: name, title: modalTitle, width, properties }));
	}, [name, modalTitle, width, component]);

	return <Button label={title} onClick={handleClick} status={status} />;
};

export default AddModalButton;
