import React, { useCallback, useMemo, useState } from 'react';

import cx from 'classnames';
import { FaChevronDown, FaChevronUp } from 'react-icons/fa';

import { isNilOrEmpty } from '@treejs/utils';

import { IMenuItem } from '../types';

type IProps = {
	isChild: boolean;
	onClick: (href: string, external: boolean) => () => void;
} & IMenuItem;

export const SidebarMenuItem = (props: IProps) => {
	const { defaultOpen, href, onClick, isChild, label, external, subMenu } = props;

	const [open, setOpen] = useState(defaultOpen);

	const handleSetOpen = useCallback(() => {
		setOpen(!open);
	}, [open]);

	const handleOnClick = useCallback(() => {
		if (!isNilOrEmpty(href)) {
			onClick(href, external)();
		} else {
			setOpen(!open);
		}
	}, [open, href, external]);

	const items = useMemo(() => {
		if (open && !isNilOrEmpty(subMenu)) {
			return subMenu.map((menuItem, i) => (
				<SidebarMenuItem key={i} isChild={true} onClick={onClick} {...menuItem} />
			));
		} else {
			return null;
		}
	}, [open, subMenu]);

	return (
		<>
			<div
				className={cx('sidebar-item', {
					'sidebar-item--isChild': isChild || false,
				})}
				onClick={handleOnClick}
			>
				<div className="align-middle">{label}</div>
				{!isNilOrEmpty(subMenu) && (
					<div className="mt-1 cursor-pointer" onClick={handleSetOpen}>
						{open ? <FaChevronUp /> : <FaChevronDown />}
					</div>
				)}
			</div>
			{items}
		</>
	);
};

export default SidebarMenuItem;
