import React, { useCallback, useEffect, useMemo, useRef, useState } from 'react';

import { isNilOrEmpty } from '@treejs/utils';

import { IMenuItem } from '../types';

type IProps = {
	children: React.ReactElement;
	items: IMenuItem[];
	onClick: (href: string, external: boolean) => () => void;
};

export const UserMenu = (props: IProps) => {
	const { items, onClick, children } = props;

	const divRef = useRef<HTMLDivElement>();

	const [open, setOpen] = useState(false);

	const handleClick = useCallback(
		(href: string, external: boolean) => () => {
			onClick(href, external)();
			setOpen(false);
		},
		[onClick]
	);

	const handleOutsideClick = useCallback((e: any) => {
		if (!divRef.current.contains(e.target)) {
			setOpen(false);
		}
	}, []);

	const handleUserMenuClick = useCallback(() => {
		setOpen(!open);
	}, [open]);

	const userItems = useMemo(() => {
		if (!isNilOrEmpty(items)) {
			return items.map(({ label, href, external }, i) => (
				<div key={i} className="user-item" onClick={handleClick(href, external)}>
					{label}
				</div>
			));
		} else {
			return null;
		}
	}, [items]);

	useEffect(() => {
		document.addEventListener('click', handleOutsideClick);
		return () => document.removeEventListener('click', handleOutsideClick);
	});

	return (
		<div ref={divRef}>
			<div className="ml-4 cursor-pointer self-center" onClick={handleUserMenuClick}>
				{children}
			</div>
			<div className="absolute top-12 right-5 z-10 bg-white shadow-lg w-60">{open && userItems}</div>
		</div>
	);
};

export default UserMenu;
