import React, { useCallback, useEffect, useState } from 'react';
import { is } from 'ramda';

type IProps = {
	max: number;
	min: number;
	onChange?: (value: number, e: React.ChangeEvent) => void;
	value?: number;
};

const Slider: React.FC<IProps> = (props) => {
	const { max, min, onChange } = props;

	const [value, setValue] = useState(props.value);

	useEffect(() => {
		if (props.value !== value) {
			setValue(value);
		}
	}, [props.value, value]);

	const handleChange = useCallback((e: React.ChangeEvent<HTMLInputElement>): void => {
		if (is(Number, e.currentTarget.value) || is(String, e.currentTarget.value)) {
			if (onChange) {
				onChange(parseInt(e.currentTarget.value), e);
			}
			setValue(parseInt(e.currentTarget.value));
		}
	}, []);

	return (
		<>
			<input
				type="range"
				className="appearance-none w-full h-4 bg-gray-400 mb-3 outline-none"
				max={max}
				min={min}
				value={value}
				onChange={handleChange}
			/>
			{value} / {max}
		</>
	);
};

Slider.displayName = 'Slider';

export default Slider;
