import React, { useMemo } from 'react';
import { compose, isNil, keys, map, mapObjIndexed, values } from 'ramda';

import { isNilOrEmpty } from '@treejs/utils';

import { ITableCol, ITableRow } from '../types';
import TableCell from './TableCell';
import TableHeaderCell from './TableHeaderCell';
import TableRow from './TableRow';

type IProps = {
	cols: ITableCol;
	nthStyle?: boolean;
	rows: ITableRow[];
};

const Table = ({ cols, rows, nthStyle = true }: IProps) => {
	const headerCells = useMemo(() => {
		if (!isNilOrEmpty(cols)) {
			return compose(
				map((c) => <TableHeaderCell key={c}>{cols[c].value}</TableHeaderCell>),
				keys
			)(cols);
		}
		return null;
	}, [cols]);

	const body = useMemo(() => {
		if (!isNilOrEmpty(rows)) {
			return values(
				mapObjIndexed(
					(row: ITableRow, rowIndex) => (
						<TableRow nthStyle={nthStyle} key={rowIndex}>
							{compose(
								map((c) => (
									<TableCell title={cols[c].value} key={c}>
										{!isNil(row[c]) && (!isNil(row[c].component) ? row[c].component : row[c].value)}
									</TableCell>
								)),
								keys
							)(cols)}
						</TableRow>
					),
					rows as any
				)
			);
		}
		return null;
	}, [cols, rows]);

	return (
		<div className="table-component">
			<div className="table-component-header-row">{headerCells}</div>
			{body}
		</div>
	);
};

Table.displayName = 'Table';

export default Table;
