import React, { useCallback } from 'react';

import { FaMinus, FaPlus } from 'react-icons/fa';

import { VERTICAL_ALIGN } from '@treejs/components/Grid/types';
import TextField from '@treejs/components/TextField';

import Button from '../../Button';
import { Grid, GridCol } from '../../Grid';

type IProps = {
	name: string;
	onChange: (a: string) => void;
	step: number;
	title: string;
	value: string;
};

const TimeButton: React.FC<IProps> = ({ title, name, onChange, value, step }) => {
	const handleChange = useCallback(
		(newValue: string): any => {
			onChange(newValue);
		},
		[onChange]
	);

	const increase = useCallback((): any => {
		const newValue = (Number(value) + step).toString();
		handleChange(newValue);
	}, [value, handleChange, step]);

	const decrease = useCallback((): any => {
		const newValue = (Number(value) - step).toString();
		handleChange(newValue);
	}, [value, handleChange, step]);

	return (
		<Grid cols={4} vertical={VERTICAL_ALIGN.BOTTOM}>
			<GridCol colSpan={1}>
				<Button label={<FaMinus />} onClick={decrease} />
			</GridCol>
			<GridCol colSpan={2}>
				<TextField
					name={name}
					title={title}
					clearable={false}
					value={value}
					onChange={handleChange}
					mask="99"
				/>
			</GridCol>
			<GridCol colSpan={1}>
				<Button label={<FaPlus />} onClick={increase} />
			</GridCol>
		</Grid>
	);
};

export default TimeButton;
