import React, { useCallback, useEffect, useState } from 'react';

import { useDispatch } from 'react-redux';

import { STATUS } from '@treejs/types/common';
import { IHTMLElement } from '@treejs/types/form';

import { openModal } from '../../Modal/actions';
import { addModalComponent } from '../../Modal/utils';
import TextField from '../../TextField';
import TimePickerModal from './TimePickerModal';

export type ITimePickerFieldProps<V = string> = {
	status?: STATUS;
	step?: {
		hour?: number;
		minute?: number;
	};
	value?: string;
} & IHTMLElement<V>;

const TimePicker: React.FC<ITimePickerFieldProps> = (props) => {
	const { onBlur, onChange, title, status, name, step } = props;

	const dispatch = useDispatch();

	const [value, setValue] = useState<string>();

	useEffect(() => {
		setValue(props.value);
	}, [props.value]);

	const handleBlur = useCallback((newValue: string, e: React.FocusEvent): void => {
		if (onBlur) {
			onBlur(newValue, e);
		}
	}, []);

	const handleTimeClick = useCallback((newValue: string): void => {
		setValue(newValue);
		if (onChange) {
			onChange(newValue, null);
		}
	}, []);

	const handleOpenModal = useCallback((): void => {
		addModalComponent(
			name,
			<TimePickerModal
				value={value}
				onChange={handleTimeClick}
				step={{ hour: step?.hour || 1, minute: step?.minute || 1 }}
			/>
		);
		dispatch(openModal({ id: name, title, width: 300 }));
	}, [name, value, title, step]);

	return (
		<TextField
			name={name}
			title={title}
			onClick={handleOpenModal}
			onFocus={handleOpenModal}
			onBlur={handleBlur}
			value={value}
			status={status}
			readonly
		/>
	);
};

export default TimePicker;
