import React, { useCallback, useEffect, useState } from 'react';

import { format, isMatch, setHours, setMinutes } from 'date-fns';

import { isNilOrEmpty } from '@treejs/utils';

import { Grid, GridCol } from '../../Grid';
import TimeButton from './TimeButton';

type IProps = {
	onChange: (value: string) => void;
	step: {
		hour: number;
		minute: number;
	};
	value: string;
};

const TimePickerModal: React.FC<IProps> = (props) => {
	const { onChange, step } = props;

	const [value, setValue] = useState<Date>(new Date());

	useEffect(() => {
		if (isMatch(props.value, 'H:mm')) {
			const today = format(new Date(), 'yyyy/MM/dd');
			setValue(new Date(`${today} ${props.value}`));
		} else {
			setValue(new Date());
		}
	}, [props.value]);

	const handleChangeHours = useCallback(
		(hourVal: string) => {
			let hour = Number(hourVal);
			if (isNilOrEmpty(hour)) {
				hour = 0;
			} else if (Number(hour) >= 24) {
				hour = 23;
			} else if (Number(hour) < 0) {
				hour = 0;
			}
			const newHour = setHours(value, hour);
			setValue(newHour);
			onChange(format(newHour, 'H:mm'));
		},
		[value, onChange]
	);

	const handleChangeMinutes = useCallback(
		(minuteVal: string) => {
			let minute = Number(minuteVal);
			if (isNilOrEmpty(minute)) {
				minute = 0;
			}
			if (Number(minute) >= 60 || Number(minute) < 0) {
				minute = 0;
			}
			const newMinute = setMinutes(value, minute);
			setValue(newMinute);
			onChange(format(newMinute, 'H:mm'));
		},
		[value, onChange]
	);

	return (
		<>
			<Grid cols={1}>
				<GridCol>
					<TimeButton
						name="hour"
						title="Hour"
						step={step.hour}
						value={format(value, 'H')}
						onChange={handleChangeHours}
					/>
				</GridCol>
				<GridCol>
					<TimeButton
						name="minute"
						title="Minute"
						step={step.minute}
						value={format(value, 'm')}
						onChange={handleChangeMinutes}
					/>
				</GridCol>
			</Grid>
		</>
	);
};

export default TimePickerModal;
