import React, { useLayoutEffect, useMemo, useState } from 'react';
import { compose, is, mapObjIndexed, values } from 'ramda';

import cx from 'classnames';

import { TITLE_SPACE_ENUM } from './types';

type IProps = {
	children?: React.ReactElement | string;
	className?: string;
	direct?: TITLE_SPACE_ENUM;
	size: number | string;
	space?: Partial<Record<TITLE_SPACE_ENUM, number>>;
};

const Title = (props: IProps): React.ReactElement => {
	const { size, space = 4, children } = props;

	const [spacing, setSpacing] = useState<string[]>();

	useLayoutEffect(() => {
		setSpacing(
			compose(
				values,
				mapObjIndexed((spaceSize, direction) => {
					return `m${direction}-${spaceSize}`;
				})
			)(space)
		);
	}, [space]);

	const textSize = useMemo(() => {
		if (!is(Number, size)) {
			return size;
		}
		return size > 1 ? `${size}xl` : 'xl';
	}, [size]);

	return <div className={cx(`text-${textSize}`, spacing)}>{children}</div>;
};

Title.displayName = 'Title';

export default Title;
