import { Dispatch } from '@reduxjs/toolkit';

import { STATUS } from '@treejs/types/common';
import { isNilOrEmpty } from '@treejs/utils';

import { TOASTER_TIMEOUT } from '../constants';
import { ACTIONS, ToasterId, ToasterOption } from '../types';

const timeouts: { [key: string]: any } = [];

export const closeToaster = (name: ToasterId) => (dispatch: Dispatch) => {
	timeouts[name] = null;
	dispatch({
		type: ACTIONS.REMOVE_TOASTER,
		payload: {
			name,
		},
	});
};

export const addToaster =
	(options: ToasterOption): any =>
	(dispatch: Dispatch<any>) => {
		if (!isNilOrEmpty(timeouts[options.name])) {
			clearTimeout(timeouts[options.name]);
		}

		timeouts[options.name] = setTimeout(() => {
			dispatch(closeToaster(options.name));
		}, options.timeout || TOASTER_TIMEOUT);

		dispatch({
			type: ACTIONS.ADD_TOASTER,
			payload: {
				status: STATUS.none,
				timeout: TOASTER_TIMEOUT,
				...options,
			},
		});
	};
