import React from 'react';

import TimePickerField from '@treejs/forms/components/fields/TimePickerField';
import { IField } from '@treejs/forms/types';

import { FIELD_TYPE } from '../constants';
import CheckboxField from './fields/CheckboxField';
import DatePickerField from './fields/DatePickerField';
import RadioButtonField from './fields/RadioButtonField';
import SelectBoxField from './fields/SelectBoxField';
import TextField from './fields/TextField';

type IProps<F> = F & IField;

function Field<F>(props: IProps<F>) {
	const { component, ...other } = props as any;

	let render = null;
	switch (component) {
		case FIELD_TYPE.TEXT_FIELD:
			render = <TextField {...other} />;
			break;
		case FIELD_TYPE.CHECKBOX:
			render = <CheckboxField {...other} />;
			break;
		case FIELD_TYPE.RADIO_BUTTON:
			render = <RadioButtonField {...other} />;
			break;
		case FIELD_TYPE.SELECT_BOX:
			render = <SelectBoxField {...other} />;
			break;
		case FIELD_TYPE.DATE_PICKER:
			render = <DatePickerField {...other} />;
			break;
		case FIELD_TYPE.TIME_PICKER:
			render = <TimePickerField {...other} />;
			break;
	}

	return <div className="field-container">{render}</div>;
}

export default Field;
