import React from 'react';
import { always } from 'ramda';

import { FormProvider, SubmitErrorHandler, SubmitHandler, UseFormReturn } from 'react-hook-form';

import { noop } from '@treejs/utils';

type IProps<FormData = Record<string, unknown>> = {
	children: React.ReactElement;
	methods: UseFormReturn<FormData>;
	onFail?: SubmitErrorHandler<FormData>;
	onSubmit: SubmitHandler<FormData>;
};

function Form<FormData>(props: IProps<FormData>) {
	const { onSubmit, onFail = always(noop), methods } = props;
	return (
		<FormProvider {...methods}>
			<form onSubmit={methods.handleSubmit(onSubmit, onFail)}>{props.children}</form>
		</FormProvider>
	);
}

export default Form;
