import React, { useEffect } from 'react';

import { useController, useFormContext } from 'react-hook-form';

import CheckBoxComponent, { ICheckboxFieldProps } from '@treejs/components/Checkbox';
import { isNilOrEmpty } from '@treejs/utils';

type IProps = ICheckboxFieldProps;

const CheckboxField = (props: IProps): React.ReactElement => {
	const { name, title, label, checked } = props;

	const {
		control,
		formState: { errors },
	} = useFormContext();
	const { field } = useController({ name, control });

	const error = errors[name];

	useEffect(() => {
		if (!isNilOrEmpty(checked)) {
			field.onChange(checked);
		}
	}, [checked]);

	return (
		<>
			<CheckBoxComponent
				name={name}
				title={title}
				checked={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				label={label}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};

export default CheckboxField;
