import React, { useEffect } from 'react';

import { useController, useFormContext } from 'react-hook-form';

import DatePickerComponent, { IDatePickerFieldProps as IDatePickerProps } from '@treejs/components/DatePicker';
import { STATUS } from '@treejs/types/common';
import { isNilOrEmpty } from '@treejs/utils';

type IProps = IDatePickerProps<string>;

const DatePickerField = (props: IProps): React.ReactElement => {
	const { name, title, value } = props;

	const {
		control,
		formState: { errors },
	} = useFormContext();
	const { field } = useController({ name, control });

	const error = errors[name];
	const status = !isNilOrEmpty(error) && STATUS.error;

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	return (
		<>
			<DatePickerComponent
				name={field.name}
				title={title}
				value={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				status={status}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};

export default DatePickerField;
