import React, { useCallback, useEffect } from 'react';
import { is } from 'ramda';

import { useController, useFormContext } from 'react-hook-form';

import RadioButtonComponent, {
	IRadioButtonFieldProps as IRadioButtonProps,
} from '@treejs/components/RadioButton/components/RadioButton';
import { IOptions } from '@treejs/types/options';
import { isNilOrEmpty } from '@treejs/utils';

export type IProps = IRadioButtonProps;

const RadioButtonField = (props: IProps): React.ReactElement => {
	const { name, title, options, horizontal, OptionRender: optionRender, onClick, value } = props;

	const {
		control,
		formState: { errors },
	} = useFormContext();
	const { field } = useController({ name, control });

	const error = errors[name];

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	const handleClick = useCallback(
		(option: IOptions, e: React.MouseEvent<HTMLInputElement>): void => {
			field.onChange(option.code);
			if (is(Function, onClick)) {
				onClick(option, e);
			}
		},
		[onClick]
	);

	return (
		<>
			<RadioButtonComponent
				name={name}
				title={title}
				value={field.value}
				options={options}
				onClick={handleClick}
				onBlur={field.onBlur}
				horizontal={horizontal}
				OptionRender={optionRender}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};

export default RadioButtonField;
