import React, { useCallback, useEffect } from 'react';
import { is } from 'ramda';

import { useController, useFormContext } from 'react-hook-form';

import SelectBoxComponent, { ISelectBoxFieldProps } from '@treejs/components/SelectBox';
import { IOption } from '@treejs/components/SelectBox/types';
import { STATUS } from '@treejs/types/common';
import { isNilOrEmpty } from '@treejs/utils';

export type IProps = ISelectBoxFieldProps;

const SelectBox = (props: IProps): React.ReactElement => {
	const { name, title, options, autoComplete, disabled, onChange, value } = props;

	const {
		control,
		formState: { errors },
	} = useFormContext();
	const { field } = useController({ name, control });

	const error = errors[name];
	const status = !isNilOrEmpty(error) && STATUS.error;

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	const handleChange = useCallback(
		(option: IOption, e: React.MouseEvent<HTMLInputElement>): void => {
			if (isNilOrEmpty(option)) {
				field.onChange(null);
				if (is(Function, onChange)) {
					onChange(undefined, e);
				}
			} else {
				field.onChange(option.code);
				if (is(Function, onChange)) {
					onChange(option, e);
				}
			}
		},
		[field]
	);

	return (
		<>
			<SelectBoxComponent
				disabled={disabled}
				name={field.name}
				title={title}
				value={field.value}
				options={options}
				onChange={handleChange}
				onBlur={field.onBlur}
				status={status}
				autoComplete={autoComplete}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};

export default SelectBox;
