import React, { useEffect } from 'react';

import { useController, useFormContext } from 'react-hook-form';

import TextFieldComponent, { ITextFieldProps } from '@treejs/components/TextField';
import { STATUS } from '@treejs/types/common';
import { isNilOrEmpty } from '@treejs/utils';

type IProps = ITextFieldProps;

const TextField: React.FC<IProps> = (props) => {
	const { name, disabled, value, ...other } = props;

	const {
		control,
		formState: { errors },
	} = useFormContext();
	const { field } = useController({ name, control });

	const error = errors[name];
	const status = !isNilOrEmpty(error) && STATUS.error;

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	return (
		<>
			<TextFieldComponent
				name={name}
				value={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				status={status}
				disabled={disabled}
				{...other}
			/>
			<div className="field-validationMessage">{!disabled && error?.message}</div>
		</>
	);
};

export default TextField;
