import React, { useEffect } from 'react';

import { useController, useFormContext } from 'react-hook-form';

import TimePickerComponent, {
	ITimePickerFieldProps as ITimePickerProps,
} from '@treejs/components/TimePicker/components/TimePicker';
import { STATUS } from '@treejs/types/common';
import { isNilOrEmpty } from '@treejs/utils';

type IProps = ITimePickerProps<string>;

const TimePickerField: React.FC<IProps> = ({ name, title, value, step }): React.ReactElement => {
	const {
		control,
		formState: { errors },
	} = useFormContext();
	const { field } = useController({ name, control });

	const error = errors[name];
	const status = !isNilOrEmpty(error) && STATUS.error;

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	return (
		<>
			<TimePickerComponent
				name={field.name}
				title={title}
				value={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				status={status}
				step={step}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};

export default TimePickerField;
