import React, { useMemo } from 'react';
import { times } from 'ramda';

import { format } from 'date-fns';

import CalendarCell from '@treejs/components/Calendar/components/CalendarCell';
import { DetailComponentProps } from '@treejs/components/Calendar/types';

export const CustomDayInMonth: React.FC<DetailComponentProps> = (props) => {
	const { value, isToday, isSelected, onClick } = props;

	const todayDay = format(value, 'dd');

	const agenda = useMemo<{ [key: string]: React.ReactElement }>(() => {
		const list: { [key: string]: React.ReactElement } = {};
		times((i) => {
			list[todayDay] = (
				<div key={i} className="text-left m-1">
					<div className="bg-primary p-1 my-1">todo</div>
				</div>
			);
		}, Math.round(Math.random()));
		return list;
	}, [todayDay, todayDay]);

	return (
		<CalendarCell isToday={isToday} isSelected={isSelected} onClick={onClick} hasValue hover value={value} border>
			<div className="p-1 h-24">
				<div className="text-right text-sm">{format(value, 'dd')}</div>
				{agenda[todayDay]}
			</div>
		</CalendarCell>
	);
};

CustomDayInMonth.displayName = 'CustomDayInMonth';
