import React, { useCallback, useMemo } from 'react';
import { times } from 'ramda';

import cx from 'classnames';
import { addMinutes, format } from 'date-fns';

import CalendarCell from '@treejs/components/Calendar/components/CalendarCell';
import { DetailComponentProps } from '@treejs/components/Calendar/types';
import { isNilOrEmpty } from '@treejs/utils';

import CalendarHourCell from './CalendarHourCell';

export const CustomDayInWeek: React.FC<DetailComponentProps> = (props) => {
	const { value, isToday, onClick, hover } = props;

	const handleClick = useCallback(
		(index) => () => {
			if (!isNilOrEmpty(onClick)) {
				const date = new Date(value);
				const dateTime = addMinutes(date.setHours(8, 0, 0, 0), 30 * index);
				onClick(dateTime);
			}
		},
		[value, onClick]
	);

	const agenda = useMemo(() => {
		return times((i) => {
			if (Math.round(Math.random())) {
				return (
					<CalendarHourCell
						key={i}
						onClick={handleClick(i)}
						className={cx({
							'hover:bg-focus': hover,
						})}
					/>
				);
			} else {
				return (
					<CalendarHourCell key={i} className="text-left">
						<div className="bg-primary h-full p-1">event</div>
					</CalendarHourCell>
				);
			}
		}, 16);
	}, []);

	return (
		<CalendarCell isToday={isToday} isSelected={false} hover={false} hasValue>
			{format(value, 'dd')}
			{agenda}
		</CalendarCell>
	);
};
