import React, { useCallback } from 'react';

import * as Yup from 'yup';

import Button from '@treejs/components/Button';
import { ICheckboxFieldProps } from '@treejs/components/Checkbox';
import { IDatePickerFieldProps } from '@treejs/components/DatePicker';
import { Grid, GridCol } from '@treejs/components/Grid';
import { IRadioButtonFieldProps } from '@treejs/components/RadioButton/components/RadioButton';
import { ISelectBoxFieldProps } from '@treejs/components/SelectBox';
import { ITextFieldProps } from '@treejs/components/TextField';
import { ITimePickerFieldProps } from '@treejs/components/TimePicker';
import Field from '@treejs/forms/components/Field';
import Form from '@treejs/forms/components/Form';
import { FIELD_TYPE } from '@treejs/forms/constants';
import { FormSubmit } from '@treejs/forms/types';
import useForm from '@treejs/forms/useForm';

type FormData = {
	checkbox: boolean;
	datePicker: string;
	radiobutton: string;
	selectBox: string;
	text: string;
	timePicker: string;
};

const radioOptions = [
	{ name: 'Field 1', code: 'field1' },
	{ name: 'Field 2', code: 'field2' },
];

const selectBoxOptions = [
	{ name: 'Option 1', code: 'option1' },
	{ name: 'Option 2', code: 'option2' },
];

const ExampleForm = () => {
	const schema: Yup.SchemaOf<FormData> = Yup.object({
		text: Yup.string().required(),
		checkbox: Yup.boolean().nullable(),
		radiobutton: Yup.string().required(),
		selectBox: Yup.string().required(),
		datePicker: Yup.string().required().nullable(),
		timePicker: Yup.string().required().nullable(),
	});

	const formMethods = useForm<FormData>({ schema });
	const { formState } = formMethods;

	const onSubmit: FormSubmit<FormData> = useCallback(
		(data) => {
			const { isDirty, dirtyFields } = formState;
			console.info(data, isDirty, dirtyFields);
		},
		[formState.dirtyFields, formState.isDirty]
	);

	return (
		<Form<FormData> onSubmit={onSubmit} methods={formMethods}>
			<Grid cols={3}>
				<GridCol colSpan={3}>
					<Field<ITextFieldProps> name="text" title="Input" component={FIELD_TYPE.TEXT_FIELD} />
					<Field<ICheckboxFieldProps> name="checkbox" title="Checkbox" component={FIELD_TYPE.CHECKBOX} />
					<Field<IRadioButtonFieldProps>
						name="radiobutton"
						title="Radio Button"
						horizontal
						options={radioOptions}
						component={FIELD_TYPE.RADIO_BUTTON}
					/>
					<Field<ISelectBoxFieldProps>
						name="selectBox"
						title="SelectBox"
						options={selectBoxOptions}
						component={FIELD_TYPE.SELECT_BOX}
					/>
					<Field<IDatePickerFieldProps>
						name="datePicker"
						title="DatePicker"
						component={FIELD_TYPE.DATE_PICKER}
					/>
					<Field<ITimePickerFieldProps>
						name="timePicker"
						title="TimePicker"
						component={FIELD_TYPE.TIME_PICKER}
					/>
				</GridCol>
				<GridCol start={2} end={2}>
					<Button type="submit" label="Send" />
				</GridCol>
			</Grid>
		</Form>
	);
};

export default ExampleForm;
