import React, { useCallback, useState } from 'react';

import { useDispatch } from 'react-redux';

import { fetchData } from '@treejs/api/actions';
import useFetch from '@treejs/api/hook/useFetch';
import { FetchMethods } from '@treejs/api/types';
import Button from '@treejs/components/Button';
import { Grid, GridCol } from '@treejs/components/Grid';
import { STATUS } from '@treejs/types/common';

import Placeholder from './Placeholder';

const URL = '/todos/1';

const FetchPage = (): React.ReactElement => {
	const dispatch = useDispatch();

	const [response, setResponse] = useState({});

	const {
		FetchLoader: Loader,
		state: { isFetching },
	} = useFetch({
		fetchPath: { url: URL, method: FetchMethods.GET },
		loaderProps: {
			placeholder: <Placeholder />,
		},
	});

	const fetch = useCallback(() => {
		dispatch(
			fetchData({
				url: URL,
				method: FetchMethods.GET,
				onSuccess: (res) => {
					setResponse(res);
				},
			})
		);
	}, []);

	return (
		<>
			<Grid cols={4}>
				<GridCol>
					<Button status={STATUS.warning} label="Odeslat" onClick={fetch} disabled={isFetching} />
				</GridCol>
			</Grid>
			<Loader>
				<pre>{JSON.stringify(response, undefined, 2)}</pre>
			</Loader>
		</>
	);
};

export default FetchPage;
