import React from 'react';

import { combineReducers, configureStore } from '@reduxjs/toolkit';
import config from 'config/config.json';
import { Provider } from 'react-redux';

import { API_REDUCER_NAME } from '@treejs/api/constants';
import { apiMiddleware } from '@treejs/api/middleware';
import apiReducer from '@treejs/api/slice';
import { AUTH_REDUCER_NAME } from '@treejs/auth/constants';
import authReducer from '@treejs/auth/slice';
import { ROOT_REDUCER_NAME } from '@treejs/constants/redux';

const store = configureStore({
	reducer: {
		[ROOT_REDUCER_NAME]: combineReducers({
			[API_REDUCER_NAME]: apiReducer,
			[AUTH_REDUCER_NAME]: authReducer,
		}),
	},
	middleware: (getDefaultMiddleware) => [
		...getDefaultMiddleware({ thunk: true }).concat(
			apiMiddleware({
				BASE_ENDPOINT_URL: config.BASE_ENDPOINT_URL,
			})
		),
	],
	devTools: true,
});

const StoreProvider: React.FC<{ children: React.ReactChild }> = ({ children }) => (
	<Provider store={store}>{children}</Provider>
);

export default StoreProvider;
